@@ -21,8 +21,11 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from typing import TYPE_CHECKING, NoReturn, Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, NoReturn, Optional, Any
 from io import BufferedIOBase
+from .input_file import InputFile
 
 if TYPE_CHECKING:
     from bale import Bot
@@ -44,8 +47,8 @@ class File:
         extra: Optional[:class:`dict`]
             The rest of the file information.
 
-        .. note::
-            You can get more information in file with :param:`extra`
+    .. note::
+        You can get more information from the file with extra.
 
     """
     __slots__ = (
@@ -80,7 +83,7 @@ class File:
         """
         return await self.bot.get_file(self.file_id)
 
-    async def save_to_memory(self, out: "BufferedIOBase") -> NoReturn:
+    async def save_to_memory(self, out: "BufferedIOBase" | Any) -> NoReturn:
         """Download this file into memory. out needs to be supplied with a :class:`io.BufferedIOBase`, the file contents will be saved to that object using the :meth:`io.BufferedIOBase.write` method.
 
         Parameters
@@ -99,6 +102,16 @@ class File:
 
         return data
 
+    def to_input_file(self) -> InputFile:
+        """Converts the file to a standard object for sending/uploading it. This object is require in the file sending methods.
+
+        Returns
+        --------
+            :class:`bale.InputFile`
+                The :class:`bale.InputFile` Object for send.
+        """
+        return InputFile(self.file_id)
+
     def __len__(self):
         return self.file_size
 
