@@ -23,16 +23,25 @@ SOFTWARE.
 """
 from __future__ import annotations
 import asyncio
-from typing import Callable, Dict, Tuple, List, Optional
+import logging
+from typing import Callable, Dict, Tuple, List, Optional, overload, NoReturn, Literal, TypeVar, Any, Coroutine
 from builtins import enumerate, reversed
 from .error import NotFound, InvalidToken
-from bale import (Message, Update, User, Components, RemoveMenuKeyboard, Chat, Price, ChatMember, HTTPClient, Updater,
-                  Photo, Document, Location, ContactMessage, Video, Audio, InputFile)
+from .utils.logging import setup_logging
+from bale import (Message, Update, User, Components, RemoveMenuKeyboard, Chat, Price, ChatMember, Updater,
+                  Location, ContactMessage, InputFile, CallbackQuery, SuccessfulPayment)
+from bale.request import HTTPClient
 
 __all__ = (
     "Bot"
 )
 
+T = TypeVar('T')
+Coro = Coroutine[Any, Any, T]
+CoroT = TypeVar('CoroT', bound=Callable[..., Coro[Any]])
+
+_log = logging.getLogger(__name__)
+
 
 class _Loop:
     __slots__ = ()
@@ -41,7 +50,6 @@ class _Loop:
         raise AttributeError((
             'loop attribute cannot be accessed in non-async contexts. '
             'Consider using either an asynchronous main function and passing it to asyncio.run or '
-            'using asynchronous initialisation hooks such as Bot.setup_hook'
         ))
 
 _loop = _Loop()
@@ -54,10 +62,11 @@ class Bot:
     ----------
         token: str 
             Bot Token
-        updater: Optional[:class:`bale.Updater`]
 
-    .. note::
-        When you create bot and run for first-step, use :meth:`bale.Bot.delete_webhook` method in `on_ready` event.
+    .. attention::
+        When you create bot and run for first-step, use :meth:`bale.Bot.delete_webhook` method in `on_before_ready` event.
+    .. admonition:: Examples
+        :any:`My First Bot <examples.basic>`
     """
     __slots__ = (
         "loop",
@@ -65,7 +74,7 @@ class Bot:
         "loop",
         "events",
         "listeners",
-        "_user",
+        "_client_user",
         "http",
         "_closed",
         "updater"
@@ -74,48 +83,134 @@ class Bot:
     def __init__(self, token: str, **kwargs):
         if not isinstance(token, str):
             raise InvalidToken()
-        self.loop = _loop
-        self.token = token
+        self.loop: asyncio.AbstractEventLoop | _Loop = _loop
+        self.token: str = token
         self.http: HTTPClient = HTTPClient(self.loop, token)
-        self._user = None
+        self._client_user = None
         self.events: Dict[str, List[Callable]] = {}
         self.listeners: Dict[str, List[Tuple[asyncio.Future, Callable[..., bool]]]] = {}
+        self._closed: bool = True
+
+        self.updater: Updater = Updater(self)
+
+    @property
+    def user(self) -> Optional["User"]:
+        """Optional[:class:`bale.User`]: Represents the connected client. ``None`` if not logged in"""
+        return self._client_user
+
+    async def _setup_hook(self):
+        loop = asyncio.get_running_loop()
+        self.loop = loop
+        self.http.loop = loop
         self._closed = False
+        await self.http.start()
 
-        self.updater: Updater = kwargs.get("updater", Updater)(self)
+    async def __aenter__(self):
+        await self._setup_hook()
+        return self
 
-    def listen(self, event_name):
-        """Register a Event"""
-        return lambda func: self.add_event(event_name, func)
+    async def __aexit__(self, exc_type, exc_value, traceback):
+        await self.close()
+        return
 
-    def add_event(self, event: str, function):
-        """Register an Event with event name"""
-        if not asyncio.iscoroutinefunction(function):
-            raise TypeError(f"{function.__name__} is not a Coroutine Function")
+    def event(self, coro: CoroT) -> CoroT:
+        """Set wrapper or listener for selected event (the name of function).
 
-        if not self.events.get(event):
-            self.events[event] = list()
+        .. hint::
+            The name of the function for which you write the decorator is considered the name of the event.
+        """
+        if not asyncio.iscoroutinefunction(coro):
+            raise TypeError('event handler must be a coroutine function')
 
-        self.events[event].append(function)
+        self.add_event(coro.__name__, coro)
+        return coro
 
-    def remove_event(self, event: str, function=None):
-        """Register an Event with event name"""
-        result = self.events.get(event)
-        if not result:
-            raise TypeError(f"{event} not in Events")
+    def listen(self, event_name: str) -> CoroT:
+        """Set wrapper or listener for selected event (custom function name).
 
-        if not function:
-            del self.events[event]
-            return
+        Parameters
+        ----------
+            event_name: :class:`str`
+                Name of the event to set.
+        """
+        def wrapper_function(func):
+            if not asyncio.iscoroutinefunction(func):
+                raise TypeError('event handler must be coroutine function')
 
-        if not function in result:
-            raise TypeError(f"{function.__name__} not in Event Functions")
+            self.add_event(event_name, func)
 
-        del self.events[event][function]
+        return wrapper_function
 
-    def wait_for(self, event_name: str, *, check=None, timeout=None):
-        """Wait for an event"""
-        self.loop: asyncio.AbstractEventLoop
+    def add_event(self, event_name: str, wrapper) -> NoReturn:
+        """Set wrapper or listener for an event.
+
+
+        Parameters
+        ----------
+            event_name: :class:`str`
+                Name of the event
+            wrapper: Callable[]
+                Function to add as wrapper for event
+        """
+        if not asyncio.iscoroutinefunction(wrapper):
+            raise TypeError(f"{wrapper.__name__} is not a Coroutine Function")
+
+        if not self.events.get(event_name):
+            self.events[event_name] = []
+
+        self.events[event_name].append(wrapper)
+
+    @overload
+    async def wait_for(self, event_name: Literal['update'], *,
+                       check: Optional[Callable[..., bool]] = None,
+                       timeout: Optional[float] = None) -> "Update":
+        ...
+
+    @overload
+    async def wait_for(self, event_name: Literal['callback_query'], *, check: Optional[Callable[..., bool]] = None,
+                       timeout: Optional[float] = None) -> "CallbackQuery":
+        ...
+
+    @overload
+    async def wait_for(self, event_name: Literal['message', 'edit_message'], *, check: Optional[Callable[..., bool]] = None,
+                       timeout: Optional[float] = None) -> "Message":
+        ...
+
+    @overload
+    async def wait_for(self, event_name: Literal['member_chat_join', 'member_chat_leave'], *, check: Optional[Callable[..., bool]] = None,
+                       timeout: Optional[float] = None) -> Tuple["Message", "Chat", "User"]:
+        ...
+
+    @overload
+    async def wait_for(self, event_name: Literal['successful_payment'], *, check: Optional[Callable[..., bool]] = None,
+                       timeout: Optional[float] = None) -> "SuccessfulPayment":
+        ...
+
+    def wait_for(self, event_name: str, *, check: Optional[Callable[..., bool]]=None, timeout: Optional[float]=None):
+        """Waits for an event to be dispatched.
+
+        This could be used to wait for a user to reply to a message, or send a photo, or to edit a message in a self-contained way.
+        The timeout parameter is passed onto asyncio.wait_for(). By default, it does not ``timeout``. Note that this does propagate the asyncio.TimeoutError for you in case of timeout and is provided for ease of use.
+        In case the event returns multiple arguments, a tuple containing those arguments is returned instead.
+        This function returns the first event that meets the requirements.
+
+        .. admonition:: Examples
+            :any:`conversation Bot <examples.conversation>`
+
+        Parameters
+        ----------
+            event_name: :class:`str`
+                Name of the event
+            check: Optional[Callable[..., :class:`bool`]]
+                A predicate to check what to wait for. The arguments must meet the parameters of the event being waited for.
+            timeout: Optional[:class:`float`]
+                The number of seconds to wait before timing out and raising asyncio.TimeoutError.
+
+        Raises
+        ------
+            asyncio.TimeoutError
+                If a timeout is provided, and it was reached.
+        """
         future = self.loop.create_future()
         event_name = event_name.lower()
         if not check:
@@ -129,24 +224,6 @@ class Bot:
         listeners.append((future, check))
         return asyncio.wait_for(future, timeout=timeout)
 
-    @property
-    def user(self) -> Optional["User"]:
-        """Optional[:class:`bale.User`]: Represents the connected client. ``None`` if not logged in"""
-        return self._user
-
-    async def setup_hook(self):
-        loop = asyncio.get_running_loop()
-        self.loop = loop
-        self.http.loop = loop
-        await self.http.start()
-
-    async def __aenter__(self):
-        await self.setup_hook()
-        return self
-
-    async def __aexit__(self, exc_type, exc_value, traceback):
-        pass
-
     async def close(self):
         """Close http Events and bot"""
         await self.http.close()
@@ -157,19 +234,20 @@ class Bot:
         """:class:`bool`: Connection Status"""
         return self._closed
 
-    async def run_event(self, core, event_name, *args, **kwargs):
+    async def run_event(self, core: CoroT, event_name: str, *args, **kwargs):
         try:
             await core(*args, **kwargs)
+        except asyncio.CancelledError:
+            pass
         except Exception as ext:
             await self.on_error(event_name, ext)
 
-    def call_to_run_event(self, core, event_name, *args, **kwargs):
+    def _create_event_schedule(self, core: CoroT, event_name: str, *args, **kwargs):
         task = self.run_event(core, event_name, *args, **kwargs)
-        self.loop: asyncio.AbstractEventLoop
         return self.loop.create_task(task, name=f"python-bale-bot: {event_name}")
 
-    def dispatch(self, event_name, /, *args, **kwargs):
-        method = "on_" + event_name
+    def dispatch(self, event_name: str, /, *args, **kwargs):
+        method = 'on_' + event_name
         listeners = self.listeners.get(event_name)
         if listeners:
             removed = []
@@ -201,11 +279,11 @@ class Bot:
         events_core = self.events.get(method)
         if events_core:
             for event_core in events_core:
-                self.call_to_run_event(event_core, method, *args, **kwargs)
+                self._create_event_schedule(event_core, method, *args, **kwargs)
 
     async def on_error(self, event_name, error):
         """a Event for get errors when exceptions"""
-        print("error", event_name, error)
+        _log.exception(f'Exception in {event_name} Ignored')
 
     async def get_bot(self) -> User:
         """Get bot information
@@ -220,15 +298,33 @@ class Bot:
                 Get bot Failed.
         """
         response = await self.http.get_bot()
-        return User.from_dict(data=response.result, bot=self)
+        client_user = User.from_dict(data=response.result, bot=self)
+        self._client_user = client_user
+        return client_user
+
+    async def set_webhook(self, url: str) -> bool:
+        """Use this method to specify an url and receive incoming updates via an outgoing webhook. Whenever there is an update for the bot, Bale will send an HTTPS POST request to the specified url, containing An Update. In case of an unsuccessful request, Bale will give up after a reasonable amount of attempts.
+
+        Parameters
+        ----------
+            url: :class:`str`
+                HTTPS url to send updates to. Use an empty string to remove webhook integration.
+
+        Returns
+        -------
+            :class:`bool`:
+                On success, True is returned.
+        """
+        response = await self.http.set_webhook(url)
+        return response or False
 
     async def delete_webhook(self) -> bool:
         """This service is used to remove the webhook set for the bot.
 
         Returns
         -------
-            bool:
-                ``True`` else ``False`` if not done
+            :class:`bool`:
+                On success, True is returned.
         Raises
         ------
             Forbidden
@@ -253,7 +349,7 @@ class Bot:
             components: Optional[:class:`bale.Components` | :class:`bale.RemoveComponents`]
                 Message Components
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
-                Additional interface options. An object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
+                If the message is a reply, ID of the original message.
         Returns
         -------
             :class:`bale.Message`
@@ -317,12 +413,12 @@ class Bot:
                 "chat_id param must be type of str or int"
             )
 
-        if not isinstance(from_chat_id, (Chat, User)):
+        if not isinstance(from_chat_id, (str, int)):
             raise TypeError(
                 "from_chat_id param must be type of str or int"
             )
 
-        if not isinstance(message_id, Message):
+        if not isinstance(message_id, (str, int)):
             raise TypeError(
                 "message_id param must be type of str or int"
             )
@@ -330,27 +426,24 @@ class Bot:
         response = await self.http.forward_message(str(chat_id), str(from_chat_id), str(message_id))
         return Message.from_dict(data=response.result, bot=self)
 
-    async def send_document(self, chat_id: str | int, document: bytes | str | "Document", *,
-                            file_name: Optional[str] = None,
+    async def send_document(self, chat_id: str | int, document: "InputFile", *,
                             caption: Optional[str] = None,
+                            components: Optional["Components" | "RemoveMenuKeyboard"] = None,
                             reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send document.
 
-        .. warning::
-            To upload a file, you must fill in the "file_name" param and end it with the file extension.
-
         Parameters
         ----------
         chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
-        document: :class:`bytes` | :class:`str` | :class:`bale.Document`
-                File to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
-        file_name: :class:`str`
-                Additional interface options. file name to send.
+        document: :class:`bale.InputFile`
+                File to send. visit :class:`bale.InputFile` to see more info.
         caption: Optional[:class:`str`]
                 Document caption.
+        components: Optional[:class:`bale.Components` | :class:`bale.RemoveComponents`]
+                Message Components
         reply_to_message_id: Optional[:class:`str` | :class:`int`]
-                Additional interface options. An object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
+                If the message is a reply, ID of the original message.
 
         Returns
         --------
@@ -371,21 +464,11 @@ class Bot:
                 "chat_id param must be type of str or int"
             )
 
-        if not isinstance(document, (bytes, str, Document)):
+        if not isinstance(document, InputFile):
             raise TypeError(
-                "document param must be type of bytes, str or Document"
+                "document param must be type of InputFile"
             )
 
-        if file_name:
-            if not isinstance(file_name, str):
-                raise TypeError(
-                    "file_name param must be type of str"
-                )
-            if isinstance(document, (str, Document)):
-                raise TypeError(
-                    "file_name param should only be used when you are uploading a file!"
-                )
-
         if reply_to_message_id and not isinstance(reply_to_message_id, (str, int)):
             raise TypeError(
                 "reply_to_message_id param must be type of str or int"
@@ -396,14 +479,21 @@ class Bot:
                 "caption param must be type of str"
             )
 
-        if isinstance(document, Document):
-            document = document.file_id
+        if components:
+            if not isinstance(components, (Components, RemoveMenuKeyboard)):
+                raise TypeError(
+                    "components param must be type of Components or RemoveComponents"
+                )
+            components = components.to_dict()
 
-        response = await self.http.send_document(chat_id, [InputFile('document', file_name, document).to_file_form_payload()], caption=caption,
+        response = await self.http.send_document(chat_id, [document.to_dict('document')], caption=caption,
+                                                 components=components,
                                                  reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
-    async def send_photo(self, chat_id: str | int, photo: bytes | str | "Photo", *, file_name: Optional[str] = None, caption: Optional[str] = None,
+    async def send_photo(self, chat_id: str | int, photo: "InputFile", *,
+                         caption: Optional[str] = None,
+                         components: Optional["Components" | "RemoveMenuKeyboard"] = None,
                          reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send photo.
 
@@ -411,14 +501,14 @@ class Bot:
         ----------
             chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
-            photo: :class:`bytes` | :class:`str` | :class:`bale.Photo`
-                Photo to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
-            file_name: :class:`str`
-                Additional interface options. file name to send.
+            photo: :class:`bale.InputFile`
+                File to send. visit :class:`bale.InputFile` to see more info.
             caption: Optional[:class:`str`]
                 Photo caption.
+            components: Optional[:class:`bale.Components` | :class:`bale.RemoveComponents`]
+                Message Components
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
-                Additional interface options. An object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
+                If the message is a reply, ID of the original message.
 
         Returns
         --------
@@ -439,23 +529,17 @@ class Bot:
                 "chat_id param must be type of str or int"
             )
 
-        if not isinstance(photo, (bytes, str, Photo)):
+        if not isinstance(photo, InputFile):
             raise TypeError(
-                "photo param must be type of bytes, str or Photo"
+                "photo param must be type of InputFile"
             )
 
-        if isinstance(photo, Photo):
-            photo = photo.file_id
-
-        if file_name:
-            if not isinstance(file_name, str):
+        if components:
+            if not isinstance(components, (Components, RemoveMenuKeyboard)):
                 raise TypeError(
-                    "file_name param must be type of str"
-                )
-            if isinstance(photo, (str, Photo)):
-                raise TypeError(
-                    "file_name param should only be used when you are uploading a file!"
+                    "components param must be type of Components or RemoveComponents"
                 )
+            components = components.to_dict()
 
         if reply_to_message_id and not isinstance(reply_to_message_id, (str, int)):
             raise TypeError(
@@ -467,11 +551,14 @@ class Bot:
                 "caption param must be type of str"
             )
 
-        response = await self.http.send_photo(str(chat_id), [InputFile('photo', file_name, photo).to_file_form_payload()], caption=caption,
+        response = await self.http.send_photo(str(chat_id), [photo.to_dict('photo')], caption=caption,
+                                              components=components,
                                               reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
-    async def send_audio(self, chat_id: str | int, audio: bytes | str | "Audio", *, file_name: Optional[str] = None, caption: Optional[str] = None,
+    async def send_audio(self, chat_id: str | int, audio: "InputFile", *,
+                         caption: Optional[str] = None,
+                         components: Optional["Components" | "RemoveMenuKeyboard"] = None,
                          reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send Audio.
 
@@ -479,14 +566,14 @@ class Bot:
         ----------
             chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
-            audio: :class:`bytes` | :class:`str` | :class:`bale.Audio`
-                Audio file to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
-            file_name: :class:`str`
-                Additional interface options. file name to send.
+            audio: :class:`bale.InputFile`
+                File to send. visit :class:`bale.InputFile` to see more info.
             caption: Optional[:class:`str`]
                 Audio caption.
+            components: Optional[:class:`bale.Components` | :class:`bale.RemoveComponents`]
+                Message Components
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
-                Additional interface options. An object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
+                If the message is a reply, ID of the original message.
 
         Returns
         --------
@@ -507,23 +594,17 @@ class Bot:
                 "chat_id param must be type of str or int"
             )
 
-        if not isinstance(audio, (bytes, str, Audio)):
+        if not isinstance(audio, InputFile):
             raise TypeError(
-                "audio param must be type of bytes, str or Audio"
+                "audio param must be type of InputFile"
             )
 
-        if isinstance(audio, Audio):
-            audio = audio.file_id
-
-        if file_name:
-            if not isinstance(file_name, str):
+        if components:
+            if not isinstance(components, (Components, RemoveMenuKeyboard)):
                 raise TypeError(
-                    "file_name param must be type of str"
-                )
-            if isinstance(audio, (str, Audio)):
-                raise TypeError(
-                    "file_name param should only be used when you are uploading a file!"
+                    "components param must be type of Components or RemoveComponents"
                 )
+            components = components.to_dict()
 
         if reply_to_message_id and not isinstance(reply_to_message_id, (str, int)):
             raise TypeError(
@@ -535,11 +616,14 @@ class Bot:
                 "caption param must be type of str"
             )
 
-        response = await self.http.send_audio(str(chat_id), [InputFile('audio', file_name, audio).to_file_form_payload()], caption=caption,
+        response = await self.http.send_audio(str(chat_id), [audio.to_dict('audio')], caption=caption,
+                                              components=components,
                                               reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
-    async def send_video(self, chat_id: str | int, video: bytes | str | "Photo", *, file_name: Optional[str] = None, caption: Optional[str] = None,
+    async def send_video(self, chat_id: str | int, video: "InputFile", *,
+                         caption: Optional[str] = None,
+                         components: Optional["Components" | "RemoveMenuKeyboard"] = None,
                          reply_to_message_id: Optional[str | int] = None) -> "Message":
         """This service is used to send Video.
 
@@ -547,14 +631,14 @@ class Bot:
         ----------
             chat_id: :class:`str` | :class:`int`
                 Unique identifier for the target chat or username of the target channel (in the format @channelusername).
-            video: :class:`bytes` | :class:`str` | :class:`bale.Photo`
-                Video to send. Pass a file_id as String to send a file that exists on the Bale servers (recommended), pass an HTTP URL as a String for Bale to get a file from the Internet, or upload a new one.
-            file_name: :class:`str`
-                Additional interface options. file name to send.
+            video: :class:`bale.InputFile`
+                File to send. visit :class:`bale.InputFile` to see more info.
             caption: Optional[:class:`str`]
                 Video caption.
+            components: Optional[:class:`bale.Components` | :class:`bale.RemoveComponents`]
+                Message Components
             reply_to_message_id: Optional[:class:`str` | :class:`int`]
-                Additional interface options. An object for an inline keyboard, custom reply keyboard, instructions to remove reply keyboard or to force a reply from the user.
+                If the message is a reply, ID of the original message.
 
         Returns
         --------
@@ -575,23 +659,17 @@ class Bot:
                 "chat_id param must be type of str or int"
             )
 
-        if not isinstance(video, (bytes, str, Video)):
+        if not isinstance(video, InputFile):
             raise TypeError(
                 "video param must be type of bytes, str or Video"
             )
 
-        if isinstance(video, Video):
-            video = video.file_id
-
-        if file_name:
-            if not isinstance(file_name, str):
+        if components:
+            if not isinstance(components, (Components, RemoveMenuKeyboard)):
                 raise TypeError(
-                    "file_name param must be type of str"
-                )
-            if isinstance(video, (str, Video)):
-                raise TypeError(
-                    "file_name param should only be used when you are uploading a file!"
+                    "components param must be type of Components or RemoveComponents"
                 )
+            components = components.to_dict()
 
         if reply_to_message_id and not isinstance(reply_to_message_id, (str, int)):
             raise TypeError(
@@ -603,7 +681,8 @@ class Bot:
                 "caption param must be type of str"
             )
 
-        response = await self.http.send_video(str(chat_id), [InputFile('video', file_name, video).to_file_form_payload()], caption=caption,
+        response = await self.http.send_video(str(chat_id), [video.to_dict('video')], caption=caption,
+                                              components=components,
                                               reply_to_message_id=reply_to_message_id)
         return Message.from_dict(data=response.result, bot=self)
 
@@ -684,12 +763,19 @@ class Bot:
 
     async def send_invoice(self, chat_id: str | int, title: str, description: str, provider_token: str,
                            prices: List["Price"], *,
+                           payload: Optional[str] = None,
                            photo_url: Optional[str] = None, need_name: Optional[bool] = False,
                            need_phone_number: Optional[bool] = False,
                            need_email: Optional[bool] = False, need_shipping_address: Optional[bool] = False,
                            is_flexible: Optional[bool] = True) -> Message:
         """You can use this service to send money request messages.
 
+        .. important::
+            When paying the amount, a fee will be charged from the sender.
+
+        .. admonition:: Examples
+            :any:`Payment Bot <examples.invoice>`
+
         Parameters
         ----------
             chat_id: :class:`str` | :class:`int`
@@ -702,6 +788,8 @@ class Bot:
                 You can use 3 methods to receive money: 1.Card number 2. Port number and acceptor number 3. Wallet number "Bale"
             prices: List[:class:`bale.Price`]
                 A list of prices.
+            payload: Optional[:class:`str`]
+                Bot-defined invoice payload. This will not be displayed to the user, use for your internal processes.
             photo_url: Optional[:class:`str`]
                 URL of the product photo for the invoice. Can be a photo of the goods or a marketing image for a service. People like it better when they see what they are paying for.
             need_name: Optional[bool]
@@ -748,6 +836,11 @@ class Bot:
                 "prices must param must be type of list"
             )
 
+        if payload and not isinstance(payload, str):
+            raise TypeError(
+                "payload param must be type of str"
+            )
+
         if photo_url and not isinstance(photo_url, str):
             raise TypeError(
                 "photo_url param must be type of str"
@@ -779,7 +872,7 @@ class Bot:
             )
 
         prices = [price.to_dict() for price in prices if isinstance(price, Price)]
-        response = await self.http.send_invoice(str(chat_id), title, description, provider_token, prices, photo_url,
+        response = await self.http.send_invoice(str(chat_id), title, description, provider_token, prices, payload, photo_url,
                                                 need_name,
                                                 need_phone_number, need_email, need_shipping_address, is_flexible)
         return Message.from_dict(data=response.result, bot=self)
@@ -919,7 +1012,7 @@ class Bot:
             )
 
         chat = await self.get_chat(user_id)
-        if chat and chat.type.is_private_chat():
+        if chat and chat.parsed_type.is_private_chat:
             return User.from_dict(chat.to_dict(), self)
 
         return None
@@ -1143,7 +1236,7 @@ class Bot:
         response = await self.http.leave_chat(str(chat_id))
         return response.result or False
 
-    async def get_updates(self, offset: int = None, limit: int = None) -> list["Update"]:
+    async def get_updates(self, offset: int = None, limit: int = None) -> List["Update"]:
         if offset and not isinstance(offset, int):
             raise TypeError(
                 "offset param must be int"
@@ -1158,20 +1251,21 @@ class Bot:
         return [Update.from_dict(data=update_payload, bot=self) for update_payload in response.result
                 if not offset or (offset and update_payload.get("update_id") > offset)] if response.result else None
 
-    async def connect(self, sleep_after_every_get_updates):
-        self._user = await self.get_bot()
-        await self.updater.start(sleep_after_every_get_updates=sleep_after_every_get_updates)
+    async def connect(self):
+        await self.get_bot()
+        await self.updater.start()
 
-    def run(self, sleep_after_every_get_updates=None):
-        """Run bot and https"""
+    def run(self):
+        """Starting the bot, updater and HTTPClient."""
 
         async def main():
             async with self:
-                await self.connect(sleep_after_every_get_updates=sleep_after_every_get_updates)
+                await self.connect()
 
+        setup_logging()
         try:
             asyncio.run(main())
-        except KeyboardInterrupt:  # Control-C
+        except KeyboardInterrupt:
             pass
         except SystemExit:
             pass
