@@ -22,125 +22,135 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 import asyncio
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Callable, Coroutine, Optional, NoReturn
+from bale import Update
+import logging
+from .error import InvalidToken, BaleError
 
 if TYPE_CHECKING:
-    from bale import Bot, Update
+    from bale import Bot
 
 __all__ = (
-    "Updater",
-    "EventType"
+    "Updater"
 )
 
-
-class EventType:
-    """This object represents an Event Type.
-
-    Attributes:
-        READY (:class:`str`): :meth:`bale.on_ready`
-        BEFORE_READY (:class:`str`): :meth:`bale.on_before_ready`
-        UPDATE (:class:`str`): :meth:`bale.on_update`
-        MESSAGE (:class:`str`): :meth:`bale.on_message`
-        EDITED_MESSAGE (:class:`str`): :meth:`bale.on_edited_message`
-        CALLBACK (:class:`str`): :meth:`bale.on_callback`
-        MEMBER_CHAT_JOIN (:class:`str`): :meth:`bale.on_member_chat_join`
-        MEMBER_CHAT_LEAVE (:class:`str`): :meth:`bale.on_member_chat_leave`
-    """
-    READY = "on_ready"
-    BEFORE_READY = "on_before_ready"
-    UPDATE = "on_update"
-    MESSAGE = "on_message"
-    EDITED_MESSAGE = "on_edited_message"
-    CALLBACK = "on_callback"
-    MEMBER_CHAT_JOIN = "on_member_chat_join"
-    MEMBER_CHAT_LEAVE = "on_member_chat_leave"
-
+_log = logging.getLogger(__name__)
 
 class Updater:
     """This object represents a Bale Bot.
 
         Attributes:
             bot (:class:`bale.Bot`): The bot used with this Updater.
-            _last_offset (int | None): Last of Offset for get updates.
-            _is_running (bool): get status of updater.
-        Args:
-            bot (:class:`bale.Bot`): The Bot Object.
     """
     __slots__ = (
         "bot",
         "_last_offset",
-        "_is_running",
+        "running",
         "__lock",
         "interval"
     )
 
     def __init__(self, bot: "Bot"):
         self.bot = bot
-        self._last_offset = None
-        self._is_running = False
+        self._last_offset: Optional[int] = None
+        self.running = False
         self.__lock = asyncio.Lock()
         self.interval = None
 
-    async def start(self, sleep_after_every_get_updates: int = None):
+    @property
+    def current_offset(self) -> Optional[int]:
+        """Optional[:class:`int`]: Represents the last offset in updates. ``None`` if Updater is not started"""
+        return self._last_offset
+
+    async def start(self):
         """Start poll event function"""
-        if self._is_running:
+        if self.running:
             raise RuntimeError("Updater is running")
-        self.interval = sleep_after_every_get_updates
+        _log.debug("Updater is in the pre-start!")
         self.bot.dispatch("before_ready")
         await self.polling()
 
-    async def polling(self):
+    async def polling(self) -> NoReturn:
         async with self.__lock:
-            if self._is_running:
+            if self.running:
                 raise RuntimeError("Updater is running")
 
             if self.bot.http.is_closed():
                 raise RuntimeError("HTTPClient is Closed")
 
-            self._is_running = True
+            self.running = True
+            self.bot.dispatch("ready")
+            _log.debug("Updater is started! (polling)")
 
             try:
                 await self._polling()
             except Exception as exc:
-                self._is_running = False
+                self.running = False
                 raise exc
 
-    async def _polling(self):
-        self.bot.dispatch("ready")
-        await self.action_getupdates()
-
-    async def action_getupdates(self):
-        while self._is_running:
+    async def _polling(self) -> NoReturn:
+        async def action_getupdates() -> bool:
             try:
                 updates = await self.bot.get_updates(offset=self._last_offset)
+            except BaleError as exc:
+                raise exc
             except Exception as exc:
-                await self.bot.on_error("getUpdates", exc)
-            else:
-                if updates:
-                    for update in updates:
-                        await self.call_to_dispatch(update)
+                _log.critical("Somthing was happened when we process Update data from bale", exc_info=exc)
+                return True
+
+            if updates:
+                for update in updates:
+                    await self.process_update(update)
+                self._last_offset = updates[-1].update_id
+
+            return True
+
+        def getupdates_error(exc) -> NoReturn:
+            _log.exception("Exception happened when polling for updates.", exc_info=exc)
+
+        await self._network_loop_retry(
+                action_getupdates,
+                getupdates_error
+            )
+
+    async def _network_loop_retry(self, action_cb: Callable[..., Coroutine], on_error_cb: Callable) -> NoReturn:
+        try:
+            while self.running:
+                try:
+                    if not await action_cb():
+                        break
+
+                except InvalidToken as exc:
+                    raise exc
+
+                except BaleError as exc:
+                    on_error_cb(exc)
 
-                    self._last_offset = updates[-1].update_id
                 if self.interval:
                     await asyncio.sleep(self.interval)
 
-    async def call_to_dispatch(self, update: "Update"):
+        except asyncio.CancelledError:
+            _log.debug("Get Updater Loop was cancelled!")
+
+    async def process_update(self, update: "Update"):
         self.bot.dispatch("update", update)
-        if update.type.is_callback_update():
+        if update.type == Update.CALLBACK_QUERY:
             self.bot.dispatch("callback", update.callback_query)
-        elif update.type.is_message_update():
+        elif update.type == Update.MESSAGE:
             self.bot.dispatch("message", update.message)
+            if update.message.successful_payment:
+                self.bot.dispatch("successful_payment", update.message.successful_payment)
             if update.message.left_chat_member:
                 self.bot.dispatch("member_chat_leave", update.message, update.message.chat, update.message.left_chat_member)
             for user in update.message.new_chat_members or []:
                 self.bot.dispatch("member_chat_join", update.message, update.message.chat, user)
-        elif update.type.is_edited_message():
+        elif update.type == Update.EDITED_MESSAGE:
             self.bot.dispatch("edited_message", update.edited_message)
 
     async def stop(self):
         """Stop running and Stop `poll_event` loop"""
         async with self.__lock:
-            if not self._is_running:
+            if not self.running:
                 raise RuntimeError("Updater is not running")
 
-            self._is_running = False
+            self.running = False
