@@ -24,7 +24,7 @@ SOFTWARE.
 from __future__ import annotations
 from typing import TYPE_CHECKING, Optional, List
 if TYPE_CHECKING:
-    from bale import Bot, Photo, Document, Components, RemoveMenuKeyboard, Price, Location, ContactMessage, Video, Audio
+    from bale import Bot, Components, RemoveMenuKeyboard, Price, Location, ContactMessage, InputFile
 
 
 class User:
@@ -32,11 +32,11 @@ class User:
 
     Attributes
     ----------
-        user_id: int
+        user_id: :class:`int`
             Unique identifier for this user or bot.
-        is_bot: bool
+        is_bot: :class:`bool`
             ``True``, if this user is a bot.
-        first_name: str
+        first_name: :class:`str`
             User’s or bot’s first name.
         last_name: Optional[:class:`str`]
             User’s or bot’s last name.
@@ -63,12 +63,12 @@ class User:
 
     @property
     def mention(self) -> str | None:
-        """Optional[:class:`str`]: User’s or bot’s mention with username."""
+        """Optional[:class:`str`]: mention user with username."""
         return f"@{self.username}" if self.username else None
 
     @property
     def chat_id(self) -> str:
-        """:class:`str`"""
+        """Aliases for :attr:`user_id`"""
         return str(self.user_id)
 
     async def send(self, text: str, components: Optional["Components" | "RemoveMenuKeyboard"] =None):
@@ -77,29 +77,29 @@ class User:
         """
         return await self.bot.send_message(self.chat_id, text, components=components)
 
-    async def send_document(self, document: bytes | str | "Document", *, file_name: Optional[str] = None, caption: Optional[str] = None):
+    async def send_document(self, document: "InputFile", *, caption: Optional[str] = None, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_document`.
         """
-        return await self.bot.send_document(self.chat_id, document, file_name=file_name, caption=caption)
+        return await self.bot.send_document(self.chat_id, document, caption=caption, components=components)
 
-    async def send_photo(self, photo: bytes | str | "Photo", *, file_name: Optional[str] = None, caption: Optional[str] = None):
+    async def send_photo(self, photo: "InputFile", *, caption: Optional[str] = None, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_photo`.
         """
-        return await self.bot.send_photo(self.chat_id, photo, file_name=file_name, caption=caption)
+        return await self.bot.send_photo(self.chat_id, photo, caption=caption, components=components)
 
-    async def send_video(self, video: bytes | str | "Video", *, file_name: Optional[str] = None, caption: Optional[str] = None):
+    async def send_video(self, video: "InputFile", *, caption: Optional[str] = None, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_video`.
         """
-        return await self.bot.send_video(self.chat_id, video, file_name=file_name, caption=caption)
+        return await self.bot.send_video(self.chat_id, video, caption=caption, components=components)
 
-    async def send_audio(self, audio: bytes | str | "Audio", *, file_name: Optional[str] = None, caption: Optional[str] = None):
+    async def send_audio(self, audio: "InputFile", *, caption: Optional[str] = None, components: Optional["Components" | "RemoveMenuKeyboard"] = None):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_audio`.
         """
-        return await self.bot.send_audio(self.chat_id, audio, file_name=file_name, caption=caption)
+        return await self.bot.send_audio(self.chat_id, audio, caption=caption, components=components)
 
     async def send_location(self, location: "Location"):
         """
@@ -113,14 +113,14 @@ class User:
         """
         return await self.bot.send_contact(self.chat_id, contact)
 
-    async def send_invoice(self, title: str, description: str, provider_token: str, prices: List["Price"], *, photo_url: Optional[str] = None,
-               need_name: Optional[bool] = False, need_phone_number: Optional[bool] = False, need_email: Optional[bool] = False,
-               need_shipping_address: Optional[bool] = False, is_flexible: Optional[bool] = True):
+    async def send_invoice(self, title: str, description: str, provider_token: str, prices: List["Price"], *, payload: Optional[str] = None,
+               photo_url: Optional[str] = None, need_name: Optional[bool] = False, need_phone_number: Optional[bool] = False,
+               need_email: Optional[bool] = False, need_shipping_address: Optional[bool] = False, is_flexible: Optional[bool] = True):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_invoice`
         """
         return await self.bot.send_invoice(self.chat_id, title, description, provider_token, prices,
-                                           photo_url=photo_url, need_name=need_name, need_email=need_email,
+                                           payload=payload, photo_url=photo_url, need_name=need_name, need_email=need_email,
                                            need_phone_number=need_phone_number, need_shipping_address=need_shipping_address, is_flexible=is_flexible)
 
     @classmethod
@@ -129,11 +129,13 @@ class User:
                    user_id=data.get("id"), bot=bot)
 
     def to_dict(self):
-        data = {"is_bot": self.is_bot,
-                "first_name": self.first_name if self.first_name is not None else None,
-                "last_name": self.last_name if self.last_name is not None else None,
-                "username": self.username if self.username is not None else None,
-                "id": self.user_id if self.user_id is not None else None}
+        data = {
+            "is_bot": self.is_bot,
+            "first_name": self.first_name,
+            "last_name": self.last_name,
+            "username": self.username,
+            "id": self.user_id
+        }
 
         return data
 
